@@ -17,7 +17,14 @@ def assignOrder(order):
     return to_func
   return do_assignment
 
-@assignOrder(7)
+@register()
+def GetMethodOrder(method):
+    '''Returns the value of the .order property on the provided method. -1 if no order is assigned'''
+    try:
+        return method.order
+    except:
+        return -1
+    
 @register()
 def OutputMethodMetadata(method):
     '''Outputs the stored metadata for the given method object'''
